A path is {:node DependencyNode :parents [DependencyNode]}. This represents a point in the dependency tree.
A path is {:node DependencyNode :parents [DependencyNode]}. This represents
a point in the dependency tree.(all-paths node)Breadth first traversal of the graph from DependencyNode node. Short circuits a path when a cycle is detected.
Breadth first traversal of the graph from DependencyNode node. Short circuits a path when a cycle is detected.
(range? {:keys [node]})Does the path point to a DependencyNode asking for a version range?
Does the path point to a DependencyNode asking for a version range?
(top-level? {:keys [parents]})Is the path a top level dependency in the project?
Is the path a top level dependency in the project?
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |